@@ -21,7 +21,7 @@
 #include "SnapBackend.h"
 #include "SnapTransaction.h"
 #include "SnapResource.h"
-#include "appstream/OdrsReviewsBackend.h"
+#include "appstream/AppStreamIntegration.h"
 #include <resources/StandardBackendUpdater.h>
 #include <resources/SourcesModel.h>
 #include <Category/Category.h>
@@ -68,9 +68,11 @@ private:
 SnapBackend::SnapBackend(QObject* parent)
     : AbstractResourcesBackend(parent)
     , m_updater(new StandardBackendUpdater(this))
-    , m_reviews(new OdrsReviewsBackend(this))
+    , m_reviews(AppStreamIntegration::global()->reviews())
 {
-    connect(m_reviews, &OdrsReviewsBackend::ratingsReady, this, &AbstractResourcesBackend::emitRatingsReady);
+    connect(m_reviews.data(), &OdrsReviewsBackend::ratingsReady, this, [this] {
+        m_reviews->emitRatingFetched(this, kTransform<QList<AbstractResource*>>(m_resources.values(), [] (AbstractResource* r) { return r; }));
+    });
 
     //make sure we populate the installed resources first
     refreshStates();
@@ -78,6 +80,8 @@ SnapBackend::SnapBackend(QObject* parent)
     SourcesModel::global()->addSourcesBackend(new SnapSourcesBackend(this));
 }
 
+SnapBackend::~SnapBackend() = default;
+
 int SnapBackend::updatesCount() const
 {
     return m_updater->updatesCount();
@@ -181,7 +185,7 @@ AbstractBackendUpdater* SnapBackend::backendUpdater() const
 
 AbstractReviewsBackend* SnapBackend::reviewsBackend() const
 {
-    return m_reviews;
+    return m_reviews.data();
 }
 
 Transaction* SnapBackend::installApplication(AbstractResource* app, const AddonList& addons)
